<?php
class ControllerCatalogTeam extends Controller {
	private $error = array();

	public function index() {
		$this->load->language('catalog/team');

		$this->document->setTitle($this->language->get('heading_title'));

		$this->load->model('catalog/team');

		$this->getList();
	}

	public function add() {
		$this->load->language('catalog/team');

		$this->document->setTitle($this->language->get('heading_title'));

		$this->load->model('catalog/team');

		if (($this->request->server['REQUEST_METHOD'] == 'POST') && $this->validateForm()) {
			$this->model_catalog_team->addTeam($this->request->post);

			$this->session->data['success'] = $this->language->get('text_success');

			$url = '';

			if (isset($this->request->get['sort'])) {
				$url .= '&sort=' . $this->request->get['sort'];
			}

			if (isset($this->request->get['order'])) {
				$url .= '&order=' . $this->request->get['order'];
			}

			if (isset($this->request->get['page'])) {
				$url .= '&page=' . $this->request->get['page'];
			}

			$this->response->redirect($this->url->link('catalog/team', 'user_token=' . $this->session->data['user_token'] . $url, true));
		}

		$this->getForm();
	}

	public function edit() {
		$this->load->language('catalog/team');

		$this->document->setTitle($this->language->get('heading_title'));

		$this->load->model('catalog/team');

		if (($this->request->server['REQUEST_METHOD'] == 'POST') && $this->validateForm()) {
			$this->model_catalog_team->editTeam($this->request->get['team_id'], $this->request->post);

			$this->session->data['success'] = $this->language->get('text_success');

			$url = '';

			if (isset($this->request->get['sort'])) {
				$url .= '&sort=' . $this->request->get['sort'];
			}

			if (isset($this->request->get['order'])) {
				$url .= '&order=' . $this->request->get['order'];
			}

			if (isset($this->request->get['page'])) {
				$url .= '&page=' . $this->request->get['page'];
			}

			$this->response->redirect($this->url->link('catalog/team', 'user_token=' . $this->session->data['user_token'] . $url, true));
		}

		$this->getForm();
	}

	public function delete() {
		$this->load->language('catalog/team');

		$this->document->setTitle($this->language->get('heading_title'));

		$this->load->model('catalog/team');

		if (isset($this->request->post['selected']) && $this->validateDelete()) {
			foreach ($this->request->post['selected'] as $team_id) {
				$this->model_catalog_team->deleteTeam($team_id);
			}

			$this->session->data['success'] = $this->language->get('text_success');

			$url = '';

			if (isset($this->request->get['sort'])) {
				$url .= '&sort=' . $this->request->get['sort'];
			}

			if (isset($this->request->get['order'])) {
				$url .= '&order=' . $this->request->get['order'];
			}

			if (isset($this->request->get['page'])) {
				$url .= '&page=' . $this->request->get['page'];
			}

			$this->response->redirect($this->url->link('catalog/team', 'user_token=' . $this->session->data['user_token'] . $url, true));
		}

		$this->getList();
	}

	protected function getList() {
		if (isset($this->request->get['sort'])) {
			$sort = $this->request->get['sort'];
		} else {
			$sort = 'team_group';
		}

		if (isset($this->request->get['order'])) {
			$order = $this->request->get['order'];
		} else {
			$order = 'ASC';
		}

		if (isset($this->request->get['page'])) {
			$page = $this->request->get['page'];
		} else {
			$page = 1;
		}

		$url = '';

		if (isset($this->request->get['sort'])) {
			$url .= '&sort=' . $this->request->get['sort'];
		}

		if (isset($this->request->get['order'])) {
			$url .= '&order=' . $this->request->get['order'];
		}

		if (isset($this->request->get['page'])) {
			$url .= '&page=' . $this->request->get['page'];
		}

		$data['breadcrumbs'] = array();

		$data['breadcrumbs'][] = array(
			'text' => $this->language->get('text_home'),
			'href' => $this->url->link('common/dashboard', 'user_token=' . $this->session->data['user_token'], true)
		);

		$data['breadcrumbs'][] = array(
			'text' => $this->language->get('heading_title'),
			'href' => $this->url->link('catalog/team', 'user_token=' . $this->session->data['user_token'] . $url, true)
		);

		$data['add'] = $this->url->link('catalog/team/add', 'user_token=' . $this->session->data['user_token'] . $url, true);
		$data['delete'] = $this->url->link('catalog/team/delete', 'user_token=' . $this->session->data['user_token'] . $url, true);

		$data['teams'] = array();
        $data['viewbutton'] = array();

		$filter_data = array(
			'sort'  => $sort,
			'order' => $order,
			'start' => ($page - 1) * $this->config->get('config_limit_admin'),
			'limit' => $this->config->get('config_limit_admin')
		);

		$team_total = $this->model_catalog_team->getTotalTeams();

		$results = $this->model_catalog_team->getTeams($filter_data);

        $this->load->model('tool/image');

		foreach ($results as $result) {
			if (is_file(DIR_IMAGE . $result['image'])) {
				$image = $this->model_tool_image->resize($result['image'], 40, 40);
			} else {
				$image = $this->model_tool_image->resize('no_image.png', 40, 40);
			}

            $data['viewbutton'][$result['team_id']][] = array(
				'name' => $this->config->get('config_name'),
				'href' => HTTP_CATALOG . 'index.php?route=information/team&team_id=' . $result['team_id']
			);

			$this->load->model('setting/site');

			$results_site = $this->model_setting_site->getSites();

			foreach ($results_site as $site) {
				$data['viewbutton'][$result['team_id']][] = array( 
					'name' => $site['name'], 
					'href' => $site['url'] . 'index.php?route=information/team&team_id=' . $result['team_id']
				);
			}

			$data['teams'][] = array(
				'team_id'     => $result['team_id'],
				'image'       => $image,
				'fullname'    => $result['fullname'],
				'team_group'  => $result['team_group'],
				'phone'       => $result['phone'],
				'email'       => $result['email'],
                'status'      => $result['status'] ? $this->language->get('text_enabled') : $this->language->get('text_disabled'),
				'sort_order'  => $result['sort_order'],
				'edit'        => $this->url->link('catalog/team/edit', 'user_token=' . $this->session->data['user_token'] . '&team_id=' . $result['team_id'] . $url, true)
			);
		}

		if (isset($this->error['warning'])) {
			$data['error_warning'] = $this->error['warning'];
		} else {
			$data['error_warning'] = '';
		}

		if (isset($this->session->data['success'])) {
			$data['success'] = $this->session->data['success'];

			unset($this->session->data['success']);
		} else {
			$data['success'] = '';
		}

		if (isset($this->request->post['selected'])) {
			$data['selected'] = (array)$this->request->post['selected'];
		} else {
			$data['selected'] = array();
		}

		$url = '';

		if ($order == 'ASC') {
			$url .= '&order=DESC';
		} else {
			$url .= '&order=ASC';
		}

		if (isset($this->request->get['page'])) {
			$url .= '&page=' . $this->request->get['page'];
		}

		$data['sort_fullname'] = $this->url->link('catalog/team', 'user_token=' . $this->session->data['user_token'] . '&sort=fullname' . $url, true);
		$data['sort_description'] = $this->url->link('catalog/team', 'user_token=' . $this->session->data['user_token'] . '&sort=td.description' . $url, true);
		$data['sort_team_group'] = $this->url->link('catalog/team', 'user_token=' . $this->session->data['user_token'] . '&sort=team_group' . $url, true);
		$data['sort_email'] = $this->url->link('catalog/team', 'user_token=' . $this->session->data['user_token'] . '&sort=email' . $url, true);
		$data['sort_status'] = $this->url->link('catalog/team', 'user_token=' . $this->session->data['user_token'] . '&sort=status' . $url, true);
		$data['sort_sort_order'] = $this->url->link('catalog/team', 'user_token=' . $this->session->data['user_token'] . '&sort=t.sort_order' . $url, true);

		$url = '';

		if (isset($this->request->get['sort'])) {
			$url .= '&sort=' . $this->request->get['sort'];
		}

		if (isset($this->request->get['order'])) {
			$url .= '&order=' . $this->request->get['order'];
		}

		$pagination = new Pagination();
		$pagination->total = $team_total;
		$pagination->page = $page;
		$pagination->limit = $this->config->get('config_limit_admin');
		$pagination->url = $this->url->link('catalog/team', 'user_token=' . $this->session->data['user_token'] . $url . '&page={page}', true);

		$data['pagination'] = $pagination->render();

		$data['results'] = sprintf($this->language->get('text_pagination'), ($team_total) ? (($page - 1) * $this->config->get('config_limit_admin')) + 1 : 0, ((($page - 1) * $this->config->get('config_limit_admin')) > ($team_total - $this->config->get('config_limit_admin'))) ? $team_total : ((($page - 1) * $this->config->get('config_limit_admin')) + $this->config->get('config_limit_admin')), $team_total, ceil($team_total / $this->config->get('config_limit_admin')));

		$data['sort'] = $sort;
		$data['order'] = $order;

		$data['header'] = $this->load->controller('common/header');
		$data['column_left'] = $this->load->controller('common/column_left');
		$data['footer'] = $this->load->controller('common/footer');

		$this->response->setOutput($this->load->view('catalog/team_list', $data));
	}

	protected function getForm() {
		$data['text_form'] = !isset($this->request->get['team_id']) ? $this->language->get('text_add') : $this->language->get('text_edit');

		if (isset($this->error['warning'])) {
			$data['error_warning'] = $this->error['warning'];
		} else {
			$data['error_warning'] = '';
		}

		if (isset($this->error['fullname'])) {
			$data['error_fullname'] = $this->error['fullname'];
		} else {
			$data['error_fullname'] = array();
		}

		if (isset($this->error['description'])) {
			$data['error_description'] = $this->error['description'];
		} else {
			$data['error_description'] = array();
		}

		if (isset($this->error['team_group'])) {
			$data['error_team_group'] = $this->error['team_group'];
		} else {
			$data['error_team_group'] = '';
		}

		if (isset($this->error['keyword'])) {
			$data['error_keyword'] = $this->error['keyword'];
		} else {
			$data['error_keyword'] = '';
		}

		$url = '';

		if (isset($this->request->get['sort'])) {
			$url .= '&sort=' . $this->request->get['sort'];
		}

		if (isset($this->request->get['order'])) {
			$url .= '&order=' . $this->request->get['order'];
		}

		if (isset($this->request->get['page'])) {
			$url .= '&page=' . $this->request->get['page'];
		}

		$data['breadcrumbs'] = array();

		$data['breadcrumbs'][] = array(
			'text' => $this->language->get('text_home'),
			'href' => $this->url->link('common/dashboard', 'user_token=' . $this->session->data['user_token'], true)
		);

		$data['breadcrumbs'][] = array(
			'text' => $this->language->get('heading_title'),
			'href' => $this->url->link('catalog/team', 'user_token=' . $this->session->data['user_token'] . $url, true)
		);

		if (!isset($this->request->get['team_id'])) {
			$data['action'] = $this->url->link('catalog/team/add', 'user_token=' . $this->session->data['user_token'] . $url, true);
		} else {
			$data['action'] = $this->url->link('catalog/team/edit', 'user_token=' . $this->session->data['user_token'] . '&team_id=' . $this->request->get['team_id'] . $url, true);
		}

		$data['cancel'] = $this->url->link('catalog/team', 'user_token=' . $this->session->data['user_token'] . $url, true);

		if (isset($this->request->get['team_id']) && ($this->request->server['REQUEST_METHOD'] != 'POST')) {
			$team_info = $this->model_catalog_team->getTeam($this->request->get['team_id']);
		}

		$this->load->model('localisation/language');

		$data['languages'] = $this->model_localisation_language->getLanguages();

		if (isset($this->request->post['team_description'])) {
			$data['team_description'] = $this->request->post['team_description'];
		} elseif (isset($this->request->get['team_id'])) {
			$data['team_description'] = $this->model_catalog_team->getTeamDescriptions($this->request->get['team_id']);
		} else {
			$data['team_description'] = array();
		}

		if (isset($this->request->post['team_group_id'])) {
			$data['team_group_id'] = $this->request->post['team_group_id'];
		} elseif (!empty($team_info)) {
			$data['team_group_id'] = $team_info['team_group_id'];
		} else {
			$data['team_group_id'] = '';
		}

		$this->load->model('catalog/team_group');

		$data['team_groups'] = $this->model_catalog_team_group->getTeamGroups();

		if (isset($this->request->post['phone'])) {
			$data['phone'] = $this->request->post['phone'];
		} elseif (!empty($team_info)) {
			$data['phone'] = $team_info['phone'];
		} else {
			$data['phone'] = '';
		}

		if (isset($this->request->post['fullname'])) {
			$data['fullname'] = $this->request->post['fullname'];
		} elseif (!empty($team_info)) {
			$data['fullname'] = $team_info['fullname'];
		} else {
			$data['fullname'] = '';
		}

		if (isset($this->request->post['email'])) {
			$data['email'] = $this->request->post['email'];
		} elseif (!empty($team_info)) {
			$data['email'] = $team_info['email'];
		} else {
			$data['email'] = '';
		}

		$this->load->model('setting/site');

		$data['sites'] = array();

		$data['sites'][] = array(
			'site_id' => 0,
			'name'    => $this->config->get('config_name'),
		);

		$sites = $this->model_setting_site->getSites();

		foreach ($sites as $site) {
			$data['sites'][] = array(
				'site_id' => $site['site_id'],
				'name'    => $site['name']
			);
		}

		if (isset($this->request->post['team_site'])) {
			$data['team_site'] = $this->request->post['team_site'];
		} elseif (isset($this->request->get['team_id'])) {
			$data['team_site'] = $this->model_catalog_team->getTeamSites($this->request->get['team_id']);
		} else {
			$data['team_site'] = array(0);
		}

		if (isset($this->request->post['image'])) {
			$data['image'] = $this->request->post['image'];
		} elseif (!empty($team_info)) {
			$data['image'] = $team_info['image'];
		} else {
			$data['image'] = '';
		}

		$this->load->model('tool/image');

		if (isset($this->request->post['image']) && is_file(DIR_IMAGE . $this->request->post['image'])) {
			$data['thumb'] = $this->model_tool_image->resize($this->request->post['image'], 100, 100);
		} elseif (!empty($team_info) && is_file(DIR_IMAGE . $team_info['image'])) {
			$data['thumb'] = $this->model_tool_image->resize($team_info['image'], 100, 100);
		} else {
			$data['thumb'] = $this->model_tool_image->resize('no_image.png', 100, 100);
		}

		$data['placeholder'] = $this->model_tool_image->resize('no_image.png', 100, 100);

		if (isset($this->request->post['status'])) {
			$data['status'] = $this->request->post['status'];
		} elseif (!empty($team_info)) {
			$data['status'] = $team_info['status'];
		} else {
			$data['status'] = true;
		}

        if (isset($this->request->post['sort_order'])) {
			$data['sort_order'] = $this->request->post['sort_order'];
		} elseif (!empty($team_info)) {
			$data['sort_order'] = $team_info['sort_order'];
		} else {
			$data['sort_order'] = '';
		}

		$data['header'] = $this->load->controller('common/header');
		$data['column_left'] = $this->load->controller('common/column_left');
		$data['footer'] = $this->load->controller('common/footer');

		$this->response->setOutput($this->load->view('catalog/team_form', $data));
	}

	protected function validateForm() {
		if (!$this->user->hasPermission('modify', 'catalog/team')) {
			$this->error['warning'] = $this->language->get('error_permission');
		}

		if (!$this->request->post['team_group_id']) {
			$this->error['team_group'] = $this->language->get('error_team_group');
		}

        if (!$this->request->post['fullname']) {
            $this->error['fullname'] = $this->language->get('error_fullname');
        }

        foreach ($this->request->post['team_description'] as $language_id => $value) {
			if ((utf8_strlen($value['description']) > 160)) {
				$this->error['description'][$language_id] = $this->language->get('error_description');
			}
		}

		if ($this->error && !isset($this->error['warning'])) {
			$this->error['warning'] = $this->language->get('error_warning');
		}

		return !$this->error;
	}

	protected function validateDelete() {
		if (!$this->user->hasPermission('modify', 'catalog/team')) {
			$this->error['warning'] = $this->language->get('error_permission');
		}

		$this->load->model('catalog/team');

		foreach ($this->request->post['selected'] as $team_id) {
			$team_total = $this->model_catalog_team->getTotalTeamsByTeamId($team_id);

			if ($team_total) {
				$this->error['warning'] = sprintf($this->language->get('error_team'), $team_total);
			}
		}

		return !$this->error;
	}

	public function autocomplete() {
		$json = array();

		if (isset($this->request->get['filter_description'])) {
			$this->load->model('catalog/team');

			$filter_data = array(
				'filter_description' => $this->request->get['filter_description'],
				'start'       => 0,
				'limit'       => 15
			);

			$results = $this->model_catalog_team->getTeams($filter_data);

			foreach ($results as $result) {
				$json[] = array(
					'team_id'     => $result['team_id'],
					'description' => strip_tags(html_entity_decode($result['description'], ENT_QUOTES, 'UTF-8')),
					'team_group'  => $result['team_group']
				);
			}
		}

		$sort_order = array();

		foreach ($json as $key => $value) {
			$sort_order[$key] = $value['description'];
		}

		array_multisort($sort_order, SORT_ASC, $json);

		$this->response->addHeader('Content-Type: application/json');
		$this->response->setOutput(json_encode($json));
	}
}
