<?php
class ControllerReportStatistics extends Controller {
	private $error = array();

	public function index() {
		$this->load->language('report/statistics');

		$this->document->setTitle($this->language->get('heading_title'));

		$this->load->model('report/statistics');

		$this->getList();
	}

	public function information() {
		$this->load->language('report/statistics');

		$this->document->setTitle($this->language->get('heading_title'));

		$this->load->model('report/statistics');

		if ($this->validate()) {
			$this->load->model('catalog/information');

			$this->model_report_statistics->editValue('information', $this->model_catalog_information->getTotalInformations(array('filter_quantity' => 0)));

			$this->session->data['success'] = $this->language->get('text_success');

			$this->response->redirect($this->url->link('report/statistics', 'user_token=' . $this->session->data['user_token'], true));
		}

		$this->getList();
	}

	public function review() {
		$this->load->language('report/statistics');

		$this->document->setTitle($this->language->get('heading_title'));

		$this->load->model('report/statistics');

		if ($this->validate()) {
			$this->load->model('catalog/review');

			$this->model_report_statistics->editValue('review', $this->model_catalog_review->getTotalReviews(array('filter_status' => 0)));

			$this->session->data['success'] = $this->language->get('text_success');

			$this->response->redirect($this->url->link('report/statistics', 'user_token=' . $this->session->data['user_token'], true));
		}

		$this->getList();
	}

	public function getList() {
		$data['breadcrumbs'] = array();

		$data['breadcrumbs'][] = array(
			'text' => $this->language->get('text_home'),
			'href' => $this->url->link('common/dashboard', 'user_token=' . $this->session->data['user_token'], true)
		);

		$data['breadcrumbs'][] = array(
			'text' => $this->language->get('heading_title'),
			'href' => $this->url->link('report/statistics', 'user_token=' . $this->session->data['user_token'], true)
		);

		$data['statistics'] = array();

		$this->load->model('report/statistics');

		$results = $this->model_report_statistics->getStatistics();

		foreach ($results as $result) {
			$data['statistics'][] = array(
				'name'  => $this->language->get('text_' . $result['code']),
				'value' => $result['value'],
				'href'  => $this->url->link('report/statistics/' . str_replace('_', '', $result['code']), 'user_token=' . $this->session->data['user_token'], true)
			);
		}

		if (isset($this->error['warning'])) {
			$data['error_warning'] = $this->error['warning'];
		} else {
			$data['error_warning'] = '';
		}

		if (isset($this->session->data['success'])) {
			$data['success'] = $this->session->data['success'];

			unset($this->session->data['success']);
		} else {
			$data['success'] = '';
		}

		$data['header'] = $this->load->controller('common/header');
		$data['column_left'] = $this->load->controller('common/column_left');
		$data['footer'] = $this->load->controller('common/footer');

		$this->response->setOutput($this->load->view('report/statistics', $data));
	}

	protected function validate() {
		if (!$this->user->hasPermission('modify', 'report/statistics')) {
			$this->error['warning'] = $this->language->get('error_permission');
		}

		return !$this->error;
	}
}